logging: Add ability to save/print current log filters

This enables the persistent configuration of let's say
'log filter imsi 012345678' for a given log file in the config
file.
diff --git a/src/Makefile.am b/src/Makefile.am
index 841f672..f2b1b83 100644
--- a/src/Makefile.am
+++ b/src/Makefile.am
@@ -1,6 +1,6 @@
 # This is _NOT_ the library release version, it's an API version.
 # Please read Chapter 6 "Library interface versions" of the libtool documentation before making any modification
-LIBVERSION=4:0:0
+LIBVERSION=5:0:0
 
 AM_CFLAGS = -Wall $(all_includes) -I$(top_srcdir)/include -I$(top_builddir)/include
 
diff --git a/src/vty/logging_vty.c b/src/vty/logging_vty.c
index 64e49d7..47877fe 100644
--- a/src/vty/logging_vty.c
+++ b/src/vty/logging_vty.c
@@ -252,7 +252,9 @@
 		tgt->filter_map & LOG_FILTER_ALL ? "Enabled" : "Disabled",
 		VTY_NEWLINE);
 
-	/* FIXME: print application specific filters */
+	/* print application specific filters */
+	if (info->print_fn)
+		info->print_fn(vty, info, tgt);
 }
 
 #define SHOW_LOG_STR "Show current logging configuration\n"
@@ -617,7 +619,9 @@
 
 	vty_out(vty, "  logging filter all %u%s",
 		tgt->filter_map & LOG_FILTER_ALL ? 1 : 0, VTY_NEWLINE);
-	/* FIXME: how to do this for filters outside of libosmocore? */
+	/* save filters outside of libosmocore, i.e. in app code */
+	if (osmo_log_info->save_fn)
+		osmo_log_info->save_fn(vty, osmo_log_info, tgt);
 
 	vty_out(vty, "  logging color %u%s", tgt->use_color ? 1 : 0,
 		VTY_NEWLINE);